@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2008 Nicolas Rougier, 2004-2008 Robert Sowada
+// Copyright (c) 2000-2010 Nicolas Rougier, 2004-2010 Robert Sowada
 //
 // This program is free software: you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -17,8 +17,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: mailbox.cc,v $
-// Revision      : $Revision: 1.92.2.3 $
-// Revision date : $Date: 2008/04/19 23:37:57 $
+// Revision      : $Revision: 1.92.2.6 $
+// Revision date : $Date: 2010/02/04 22:42:08 $
 // Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
@@ -79,7 +79,7 @@ Mailbox::Mailbox (const Mailbox &other)
 	add_option ((Mailbox &)other);
 
 	status (MAILBOX_UNKNOWN);
-	timetag_= 0;
+	timetag_ = 0;
 	mutex_ = g_mutex_new ();
 	monitor_mutex_ = g_mutex_new ();
 }
@@ -134,23 +134,27 @@ Mailbox::threaded_start (guint delay)
 #endif
 }
 
-gboolean
+gboolean 
 Mailbox::start_delayed_entry_point (gpointer data)
 {
 	GError *err = NULL;
-	g_thread_create ((GThreadFunc) start_entry_point, data, FALSE, &err);
+
+	static_cast<Mailbox *>(data)->timetag (0);
+
+	g_thread_create ((GThreadFunc) start_entry_point, data, false, &err);
 	if (err != NULL)  {
-		g_warning (_("[%d] Unable to create thread: %s"), MAILBOX(data)->uin(), err->message);
+		g_warning (_("[%d] Unable to create thread: %s"),
+				   static_cast<Mailbox *>(data)->uin(), err->message);
 		g_error_free (err);
 	}
-	MAILBOX(data)->timetag (0);
+
 	return false;
 }
 
 void
 Mailbox::start_entry_point (gpointer data)
 {
-	MAILBOX(data)->start();
+	static_cast<Mailbox *>(data)->start();
 }
 
 void
@@ -252,8 +256,8 @@ Mailbox::option_changed (Option *option)
 
 	// DELAY
 	if (option->name() == "delay") {
-		value ("delay_minutes", ((Option_UInt *)option)->value()/60, false);
-		value ("delay_seconds", ((Option_UInt *)option)->value()%60, false);
+		value ("delay_minutes", (static_cast<Option_UInt *>(option))->value()/60, false);
+		value ("delay_seconds", (static_cast<Option_UInt *>(option))->value()%60, false);
 		return;
 	}
 
@@ -297,7 +301,7 @@ Mailbox::option_changed (Option *option)
 	// PASSWORD_AES
 	if (option->name() == "password_aes") {
 		std::string decpass = decrypt_aes (biff_->value_string ("passphrase"),
-										   ((Option_String *)option)->value());  
+										   (static_cast<Option_String *>(option))->value());  
 		value ("password", decpass);
 		return;
 	}
@@ -313,7 +317,7 @@ Mailbox::option_changed (Option *option)
 	if (option->name() == "uin") {
 		if (value_string("name").size() == 0) {
 			gchar *text = g_strdup_printf (_("mailbox %d"),
-										   ((Option_UInt *)option)->value());
+										   (static_cast<Option_UInt *>(option))->value());
 			value ("name", text);
 			g_free (text);
 		}
@@ -344,7 +348,7 @@ Mailbox::option_update (Option *option)
 	if (option->name() == "password_aes") {
 		std::string enc_aes = encrypt_aes (biff_->value_string ("passphrase"),
 										   value_string ("password"));
-		((Option_String *)option)->value (enc_aes);
+		(static_cast<Option_String *>(option))->value (enc_aes);
 		return;
 	}
 #endif
@@ -838,8 +842,12 @@ void Mailbox::parse (std::vector<std::string> &mail, std::string uid,
 #ifdef DEBUG
 		g_message ("[%d] Parsed message with id \"%s\"", uin(),
 				   h.mailid().c_str ());
+#endif
 	}
 	else {
+		// Store filtered messages so that they are fetched next time
+		hidden_.insert (h.mailid());
+#ifdef DEBUG
 		g_message ("[%d] Parsed and discarded message with id \"%s\"", uin(),
 				   h.mailid().c_str ());
 #endif
@@ -1062,16 +1070,17 @@ Mailbox::new_mail(std::string &mailid)
 	// Mail shall not be displayed? -> no need to fetch and parse it
 	if (hidden_.find (mailid) != hidden_.end ()) {
 #ifdef DEBUG
-		g_message ("[%d] Ignore mail with id \"%s\"", uin(), mailid.c_str ());
+		g_message ("[%d] Ignore message with id \"%s\"", uin(),
+				   mailid.c_str ());
 #endif
 		return true;
 	}
 
-	// Mail unknown?
+	// Message unknown?
 	if (unread_.find (mailid) == unread_.end ())
 		return false;
 
-	// Insert known mail into new unread mail map
+	// Insert known message into new unread mail map
 	new_unread_[mailid] = unread_[mailid];
 	new_unread_[mailid].position (new_unread_.size());
 
