@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2007 Nicolas Rougier, 2004-2007 Robert Sowada
+// Copyright (c) 2000-2011 Nicolas Rougier, 2004-2011 Robert Sowada
 //
 // This program is free software: you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -17,8 +17,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: ui-properties.h,v $
-// Revision      : $Revision: 1.6.2.2 $
-// Revision date : $Date: 2008/04/25 22:53:16 $
+// Revision      : $Revision: 1.6.2.4 $
+// Revision date : $Date: 2011/12/29 12:46:53 $
 // Author(s)     : Nicolas Rougier, Robert Sowada
 // Short         : 
 //
@@ -48,10 +48,8 @@ class Properties : public GUI {
 protected:
 	class Preferences *	preferences_;
 	class Mailbox	*	mailbox_;
-	GtkUIManager *		type_manager_;
-	GtkWidget *			type_menu_;
-	GtkUIManager *		auth_manager_;
-	GtkWidget *			auth_menu_;
+    GtkComboBoxText     *auth_cbox_;
+    GtkComboBoxText     *type_cbox_;
 	GtkSizeGroup *		group_;
 
 	gint				selected_type_;
@@ -94,8 +92,8 @@ public:
 	void on_delay					(GtkWidget *widget);
 	void on_port					(GtkWidget *widget);
 	void on_mailbox					(GtkWidget *widget);
-	void on_type_changed			(GtkAction *action);
-	void on_auth_changed			(GtkAction *action);
+	void on_type_changed			(void);
+	void on_auth_changed			(void);
 	void on_browse_address			(GtkWidget *widget);
 	void on_browse_certificate		(GtkWidget *widget);
 	void on_ok						(GtkWidget *widget);
